@@ -10,6 +10,14 @@
  * added toggle all.
  *
  * NOTE: Modified from addrbook_search from /functions/
+ *
+ * Version v0.11 - corrected the displayed text that is next to the
+ *                 search box, since the search wasn't being performed
+ *                 on the 'address' but on the 'name'
+ *                   
+ *                 Modified: May 11th 2004 - Bryan Loniewski
+ *                                           brylon@jla.rutgers.edu
+ *
  */
 if (!defined('SM_PATH'))define('SM_PATH','../../');
 
@@ -131,7 +139,7 @@ $abook = addressbook_init();
         bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
         textdomain('abook_group');
 	echo '<TABLE BORDER="0" WIDTH="100%" >' . '<TR><TD NOWRAP VALIGN=middle>' . "\n" .
-         '  <STRONG>' . _("Search for address to add") . "</STRONG>\n" .
+         '  <STRONG>' . _("Search for name to add") . "</STRONG>\n" .
          '  <INPUT TYPE=text NAME=query VALUE="' . htmlspecialchars($query) .
          "\" SIZE=26>\n";
          bindtextdomain('squirrelmail', SM_PATH . 'locale');
