@@ -22,11 +22,12 @@ include_once(SM_PATH . 'plugins/abook_group/abook_group_functions.php');
 
 /* --- End functions --- */
 
-global $mailbox, $username;
+global $username;
 
 /* Set globals */
 sqgetGlobalVar('username', $username, SQ_POST);
-sqgetGlobalVar('mailbox', $mailbox, SQ_POST);
+// we are not in mailbox
+// sqgetGlobalVar('mailbox', $mailbox, SQ_POST);
 sqgetGlobalVar('myparams', $myparams, SQ_POST);
 sqgetGlobalVar('abook', $abook, SQ_POST);
 sqgetGlobalVar('nickNameBackEnd', $nickNameBackEnd, SQ_POST);
@@ -43,7 +44,7 @@ sqgetGlobalVar('backendName', $backendName, SQ_POST);
 
 /* End globals */
 
-displayPageHeader($color, $mailbox);
+displayPageHeader($color, 'None');
 
 /* Initialize addressbook */
 $abook = addressbook_init();
@@ -56,9 +57,7 @@ $myparams['owner'] = $username;
 $abookGroups = new abook_group_database($myparams);
 if (isset($remove) && !empty($remove)){
        if (isset($nickNameBackEnd) && !empty($nickNameBackEnd)){
-
            $userData = explodeUserArray($nickNameBackEnd);
-
            $abookGroups->removeFromGroup($userData, $groupName);
 
            if ($abookGroups->error){
@@ -75,6 +74,7 @@ if (isset($remove) && !empty($remove)){
 
 }
 
+
 $myGroupMembers = $abookGroups->list_groupMembers($groupName);
 
 ?>
@@ -106,7 +106,7 @@ $myGroupMembers = $abookGroups->list_groupMembers($groupName);
         $name = $myGroupMembers[$j]['name'];
 		$nickName = $myGroupMembers[$j]['nickname'];
 		$backendName = $abook->backends[$myGroupMembers[$j]['backend']]->sname;
-#$backendName = addslashes ($backendName);
+
 ?>		
 <tr><td>
 
